OC.L10N.register(
    "calendar",
    {
    "Calendar" : "تقویم",
    "Hello," : "سلام،",
    "Individual" : "تک",
    "Group" : "گروه",
    "Resource" : "منابع",
    "Room" : "اتاق",
    "Unknown" : "نامشخص",
    "Required" : "اجباری",
    "Optional" : "اختیاری",
    "{name} ({email})" : "{name} ({email})",
    "New event" : "رویداد جدید",
    "group" : "گروه",
    "Attendees" : "شرکت کنندگان",
    "Repeating" : "در حال تکرار کردن",
    "Cancelled" : "لغو شده",
    "Global" : "عمومی",
    "None" : "هیچ‌کدام",
    "Every day" : "هر روز",
    "Every week" : "هر هفته",
    "Every month" : "هر ماه",
    "Every year" : "هر سال",
    "never" : "هرگز",
    "after" : "بعد از",
    "Audio" : "صدا",
    "Email" : "ایمیل",
    "sec" : "ثانیه",
    "min" : "دقیقه",
    "hours" : "ساعت",
    "days" : "روز",
    "week" : "هفته",
    "before" : "قبل",
    "start" : "آغاز",
    "end" : "پایان",
    "Title of the Event" : "عنوان رویداد",
    "Delete" : "حذف",
    "Cancel" : "منصرف شدن",
    "Create" : "ایجاد کردن",
    "Update" : "به روز رسانی",
    "Close" : "بستن",
    "Location" : "محل",
    "Description" : "توضیحات",
    "Export" : "گرفتن خروجی",
    "Day" : "روز",
    "Week" : "هفته",
    "Month" : "ماه",
    "Today" : "امروز",
    "Share Calendar" : "تقویم را به اشتراک بگذارید",
    "Shared" : "اشتراک گذاشته شده",
    "More" : "بیش‌تر",
    "Edit" : "ویرایش",
    "Link" : "لینک",
    "Download" : "دانلود",
    "can edit" : "می توان ویرایش کرد",
    "New Calendar" : "تقویم جدید",
    "Name" : "نام",
    "Edit event" : "ویرایش رویداد",
    "Time" : "زمان",
    "Type" : "نوع",
    "Repeat" : "تکرار",
    "Add" : "افزودن",
    "from" : "از",
    "to" : "به",
    "New calendar" : "تقویم جدید",
    "Primary CalDAV address" : "آدرس اولیه CalDAV",
    "iOS/OS X CalDAV address" : "آدرس CalDAV مربوط به iOS/OS X"
},
"nplurals=1; plural=0;");
